import { GitLabError } from "../errors/GitLabError.js";
import { GitLabAuthError } from "../errors/GitLabAuthError.js";
export class Command {
    constructor(url, method, path, token) {
        this.url = url;
        this.path = path;
        this.token = token;
        this.method = method;
    }
    async execute(body, json = true) {
        const init = {
            method: this.method,
            headers: new Headers({
                "Authorization": `Bearer ${this.token}`,
                ...(body !== undefined && { "Content-Type": "application/json" })
            }),
        };
        if (body !== undefined) {
            init.body = JSON.stringify(body);
        }
        const res = await fetch(`${this.url}/api/v4/${this.path}`, init);
        if (!json) {
            return res;
        }
        else if (res.ok) {
            return await res.json();
        }
        else {
            const errorResponse = await res.json();
            if ((await res.status) === 401) {
                throw new GitLabAuthError(errorResponse.error);
            }
            throw new GitLabError(`Error from server: ${errorResponse.error ?? 'Unknown error'}`);
        }
    }
}
//# sourceMappingURL=Command.js.map