import { UndoableCommand } from "./UndoableCommand.js";
import { RevertCommitCommand } from "./RevertCommitCommand.js";
export class CommitCommand extends UndoableCommand {
    constructor(url, token, projectId, actions, message, branch = 'branch') {
        super(url, 'POST', `projects/${projectId}/repository/commits`, token);
        this.projectId = projectId;
        this.actions = actions;
        this.message = message;
        this.branch = branch;
    }
    async execute() {
        const response = await super.execute({
            branch: this.branch,
            commit_message: this.message,
            actions: this.actions
        });
        this.sha = response.id;
        return response;
    }
    async undo() {
        if (this.token && this.sha) {
            return (await new RevertCommitCommand(this.url, this.token, this.projectId, this.sha, this.branch).execute());
        }
    }
}
//# sourceMappingURL=CommitCommand.js.map