import { UndoableCommand } from "./UndoableCommand.js";
import { DeleteMergeRequestCommand } from "./DeleteMergeRequestCommand.js";
import { CloseMergeRequestCommand } from "./CloseMergeRequestCommand.js";
export class CreateMergeRequestCommand extends UndoableCommand {
    constructor(url, token, id, title, sourceBranch, targetBranch = 'main') {
        super(url, 'POST', `projects/${id}/merge_requests`, token);
        this.id = id;
        this.title = title;
        this.sourceBranch = sourceBranch;
        this.targetBranch = targetBranch;
    }
    async execute() {
        const response = await super.execute({
            id: this.id,
            title: this.title,
            source_branch: this.sourceBranch,
            target_branch: this.targetBranch,
        });
        this.mergeRequestIid = response.iid;
        return response;
    }
    async undo() {
        if (this.token && this.id && this.mergeRequestIid) {
            try {
                return (await new DeleteMergeRequestCommand(this.url, this.token, this.id, this.mergeRequestIid).execute());
            }
            catch (error) {
                return (await new CloseMergeRequestCommand(this.url, this.token, this.id, this.mergeRequestIid).execute());
            }
        }
    }
}
//# sourceMappingURL=CreateMergeRequestCommand.js.map