import { GitLabAuthError } from "../errors/GitLabAuthError.js";
import { Command } from "./Command.js";
export class RefreshAccessTokenCommand extends Command {
    constructor(url, refreshToken, clientId, clientSecret, redirectUri) {
        super(url, 'POST', `oauth/token`);
        this.refreshToken = refreshToken;
        this.clientId = clientId;
        this.clientSecret = clientSecret;
        this.redirectUri = redirectUri;
    }
    async execute() {
        const init = {
            method: this.method,
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify({
                grant_type: 'refresh_token',
                client_id: this.clientId,
                client_secret: this.clientSecret,
                refresh_token: this.refreshToken,
                redirect_uri: this.redirectUri
            }),
        };
        const res = await fetch(`${this.url}/${this.path}`, init);
        const json = await res.json();
        if (res.ok) {
            return json;
        }
        else {
            throw new GitLabAuthError(json);
        }
    }
}
//# sourceMappingURL=RefreshAccessTokenCommand.js.map